package com.ruoyi.app.service;

import com.ruoyi.app.domain.AppLedConfig;

import java.util.List;

/**
 * 【请填写功能名称】Service接口
 *
 * @author ruoyi
 * @date 2025-01-14
 */
public interface IAppLedConfigService
{
    /**
     * 查询【请填写功能名称】
     *
     * @param ledId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public AppLedConfig selectAppLedConfigByLedId(String ledId);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param appLedConfig 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<AppLedConfig> selectAppLedConfigList(AppLedConfig appLedConfig);

    /**
     * 新增【请填写功能名称】
     *
     * @param appLedConfig 【请填写功能名称】
     * @return 结果
     */
    public int insertAppLedConfig(AppLedConfig appLedConfig);

    /**
     * 修改【请填写功能名称】
     *
     * @param appLedConfig 【请填写功能名称】
     * @return 结果
     */
    public int updateAppLedConfig(AppLedConfig appLedConfig);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ledIds 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteAppLedConfigByLedIds(String[] ledIds);

    /**
     * 删除【请填写功能名称】信息
     *
     * @param ledId 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteAppLedConfigByLedId(String ledId);
}
