package com.ruoyi.web.controller.app;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.app.domain.AppGoodsPair;
import com.ruoyi.app.domain.AppLedConfig;
import com.ruoyi.app.service.IAppLedConfigService;
import com.ruoyi.web.controller.section.EnhanceDataList;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 *
 * @author ruoyi
 * @date 2025-01-15
 */
@RestController
@RequestMapping("/app/led")
public class AppLedConfigController extends BaseController
{
    @Autowired
    private IAppLedConfigService appLedConfigService;

    /**
     * 查询【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:config:list')")
    @GetMapping("/list")
    @EnhanceDataList(entityType = AppLedConfig.class)
    public TableDataInfo list(AppLedConfig appLedConfig)
    {
        startPage();
        List<AppLedConfig> list = appLedConfigService.selectAppLedConfigList(appLedConfig);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:config:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppLedConfig appLedConfig)
    {
        List<AppLedConfig> list = appLedConfigService.selectAppLedConfigList(appLedConfig);
        ExcelUtil<AppLedConfig> util = new ExcelUtil<AppLedConfig>(AppLedConfig.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:config:query')")
    @GetMapping(value = "/{ledId}")
    public AjaxResult getInfo(@PathVariable("ledId") String ledId)
    {
        return success(appLedConfigService.selectAppLedConfigByLedId(ledId));
    }

    /**
     * 新增【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:config:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppLedConfig appLedConfig)
    {
        return toAjax(appLedConfigService.insertAppLedConfig(appLedConfig));
    }

    /**
     * 修改【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:config:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppLedConfig appLedConfig)
    {
        return toAjax(appLedConfigService.updateAppLedConfig(appLedConfig));
    }

    /**
     * 删除【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:config:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ledIds}")
    public AjaxResult remove(@PathVariable String[] ledIds)
    {
        return toAjax(appLedConfigService.deleteAppLedConfigByLedIds(ledIds));
    }
}
